@@ -32,4 +32,15 @@ insert_after ("dh_installchangelogs", "dh_octave_changelogs");
 insert_after ("dh_installexamples", "dh_octave_examples");
 insert_before ("dh_installdeb", "dh_octave_substvar");
 
+# The following is necessary, otherwise dpkg-shlibdeps will not find
+# the liboctmex library, against which the .mex files are linked.
+# This issue arose with Octave v10.
+
+my $octave_version = qx {/usr/bin/octave-config --print VERSION};
+$octave_version =~ s/\s+$//g;
+add_command_options (
+    "dh_shlibdeps",
+    "-l/usr/lib/$ENV{DEB_HOST_MULTIARCH}/octave/$octave_version"
+);
+
 1;
